/*
 * $Id: seconds.c,v 1.13 2001/12/06 02:24:12 dholm Exp $
 */

/*
 * Harbour Project source code:
 * SECONDS() function
 *
 * Copyright 1999 Jose Lalin <dezac@corevia.com>
 * www - http://www.harbour-project.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307 USA (or visit the web site http://www.gnu.org/).
 *
 * As a special exception, the Harbour Project gives permission for
 * additional uses of the text contained in its release of Harbour.
 *
 * The exception is that, if you link the Harbour libraries with other
 * files to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the Harbour library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the Harbour
 * Project under the name Harbour.  If you copy code from other
 * Harbour Project or Free Software Foundation releases into a copy of
 * Harbour, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for Harbour, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.
 *
 */

#include "hbapi.h"

#include <time.h>
#if defined( HB_OS_BSD)
   #include <sys/time.h>
#elif defined( OS_UNIX_COMPATIBLE )
   #include <sys/timeb.h>
#else
   #include <sys\timeb.h>
#endif

double hb_dateSeconds( void )
{
#if defined(_MSC_VER)
   #define timeb _timeb
   #define ftime _ftime
#endif
#if defined(HB_OS_BSD)
   struct timeval tv;
   struct timezone tz;
#else
   struct timeb tb;
#endif
   time_t seconds;
   time_t fraction;
   struct tm * oTime;

   HB_TRACE(HB_TR_DEBUG, ("hb_dateSeconds()"));

#if defined(HB_OS_BSD)
   gettimeofday( &tv, &tz );
   seconds = tv.tv_sec;
   fraction = tv.tv_usec / 1000U;
#else
   ftime( &tb );
   seconds = tb.time;
   fraction = tb.millitm;
#endif

   oTime = localtime( &seconds );

   return ( oTime->tm_hour * 3600 ) +
          ( oTime->tm_min * 60 ) +
            oTime->tm_sec +
          ( ( double ) fraction / 1000.0 );
}

HB_FUNC( SECONDS )
{
   hb_retnd( hb_dateSeconds() );
}

#ifdef HB_EXTENSION

HB_FUNC( HB_CLOCKS2SECS )
{
   hb_retnd((double) hb_parnl( 1 ) / CLOCKS_PER_SEC );
}

#endif









